function rate = f_identify_subject_orig_FCs(learning_matrix,validation_matrix,labels_learning,labels_validation,configs)

numSubjs = configs.numSubjs;

num_learning_tasks = size(learning_matrix,2)/numSubjs;
num_validation_tasks = size(validation_matrix,2)/numSubjs;

% Define the identification mask which, at the end, would contain 0 for a correct identification
% and for the incorrect identification, would contain the label of the subject for
% which a given FC was mistaken for (Subject Identification Mask)
sim = zeros(1,length(labels_validation));

%% Identification Stage
disp('performing subject-identification using Orig FCs')

% Create average representations
learning_matrix_avg = nan(size(learning_matrix,1),numSubjs);
for s = 1:numSubjs
    learning_subj = learning_matrix(:,(s-1)*num_learning_tasks+1:(s-1)*num_learning_tasks+num_learning_tasks);
    learning_matrix_avg(:,s) = mean(learning_subj,2);
end
I = corr(learning_matrix_avg,validation_matrix);
[~,index_prediction] = max(I);
labels_learning_avg = labels_learning(1:num_learning_tasks:end);
labels_prediction = labels_learning_avg(index_prediction);
sim(labels_prediction ~= labels_validation) = labels_prediction(labels_prediction ~= labels_validation);

%% Compute Subject-Identification (SI) rates for each of the validation tasks separately
rate = nan(1,num_validation_tasks);
for i = 1:num_validation_tasks % for each task
    temp = sim(i:num_validation_tasks:end);
    rate(i) = nnz(temp == 0)/numSubjs;
end