function [rate,CM,rate_null,CM_null] = f_identify_task_GEFF(learning_matrix,validation_matrix,labels_learning,labels_validation,configs)

numTasks = configs.numTasks;

%% Perform the PCA to get the eigenvectors and the corresponding weights
% disp('Perfoming PCA ...');
[COEFF,SCORE,LATENT] = pca(learning_matrix); 
max_num_comps = size(COEFF,2);

%% Compute eigenspace representations for all the FCs from the validation dataset
n = size(learning_matrix,1);
S = diag(sqrt(LATENT*(n-1)));

X = bsxfun(@minus,validation_matrix,mean(validation_matrix));
beta_validation = (S*S)\SCORE'*X;

%% Identification Stage (Setup)
num_learning_subjs = size(learning_matrix,2)/numTasks;
num_validation_subjs = size(validation_matrix,2)/numTasks;

% Permute the validation labels for the null model
labels_validation_null = labels_validation(randperm(length(labels_validation)));

%% Compute the centroids (average subject-representaions) for later use
% initialization for centroids coordinates in the eigenspace
cg_all = nan(max_num_comps,numTasks); 
for i = 1:max_num_comps
    % Reshape a specific eigenvector, so it could be averaged across learning tasks
    comp = reshape(COEFF(:,i),num_learning_subjs,numTasks); 
    
    % Compute the centroid
    cg_all(i,:) = mean(comp,1); 
end
labels_learning_avg = labels_learning(1:num_learning_subjs:end);

%% Identification Stage (computation)
disp('performing task-identification using GEFF')

% Define the identification mask which, at the end, would contain 0 for a correct identification
% and for the incorrect identification, would contain the label of the task for
% which a given FC was mistaken for (Task Identification Mask)
tim = zeros(max_num_comps,length(labels_validation));
tim_null = zeros(max_num_comps,length(labels_validation));

% Initialize a variable for explained variance
R2 = zeros(1,max_num_comps);

for i = 1:max_num_comps
        
    R2(i) = sum(LATENT(1:i))./sum(LATENT);
    
    % Get the centroids for the desired eigenvectors
    cg = cg_all(1:i,:); 
    
    beta_validation_i = beta_validation(1:i,:);
        
    % Compute the distance from all the centroids of subjects
    D = pdist2(cg',beta_validation_i','cosine');
        
    [~,ind] = min(D);
    prediction_labels = labels_learning_avg(ind);
    tim(i,prediction_labels ~= labels_validation) = prediction_labels(prediction_labels ~= labels_validation);
    tim_null(i,prediction_labels ~= labels_validation_null) = prediction_labels(prediction_labels ~= labels_validation_null);
    
end

%% Compute Task-Identification (TI) rates and confusion matrix
% The rates are computed for increasing number of eigenvectors
rate = nan(max_num_comps,numTasks);
CM = nan(max_num_comps,numTasks,numTasks);
rate_null = nan(max_num_comps,numTasks);
CM_null = nan(max_num_comps,numTasks,numTasks);

for i = 1:max_num_comps
    for j = 1:numTasks
        temp = tim(i,(j-1)*num_validation_subjs+1:(j-1)*num_validation_subjs+num_validation_subjs);
        rate(i,j) = nnz(temp == 0)/num_validation_subjs;
        
        % Confusion Matrix
        for k = 1:numTasks
            if j == k
                CM(i,j,k) = nnz(temp == 0)/num_validation_subjs;
            else
                CM(i,j,k) = nnz(temp == k)/num_validation_subjs;
            end
        end
        
        temp = tim_null(i,(j-1)*num_validation_subjs+1:(j-1)*num_validation_subjs+num_validation_subjs);
        rate_null(i,j) = nnz(temp == 0)/num_validation_subjs;
        
        % Confusion Matrix for the null model
        for k = 1:numTasks
            if j == k
                CM_null(i,j,k) = nnz(temp == 0)/num_validation_subjs;
            else
                CM_null(i,j,k) = nnz(temp == k)/num_validation_subjs;
            end
        end
    end
end















































