function [rate,CM] = f_identify_task_orig_FCs(learning_matrix,validation_matrix,labels_learning,labels_validation,configs)

numTasks = configs.numTasks;

num_learning_subjs = size(learning_matrix,2)/numTasks;
num_validation_subjs = size(validation_matrix,2)/numTasks;

% Define the identification mask which, at the end, would contain 0 for a correct identification
% and for the incorrect identification, would contain the label of the task for
% which a given FC was mistaken for (Task Identification Mask)
tim = zeros(1,length(labels_validation));

%% Identification Stage
disp('performing task-identification using Orig FCs')

% Create average representations
learning_matrix_avg = nan(size(learning_matrix,1),numTasks);
for t = 1:numTasks
    learning_task = learning_matrix(:,(t-1)*num_learning_subjs+1:(t-1)*num_learning_subjs+num_learning_subjs);
    learning_matrix_avg(:,t) = mean(learning_task,2);
end
I = corr(learning_matrix_avg,validation_matrix);
[~,index_prediction] = max(I);
labels_learning_avg = labels_learning(1:num_learning_subjs:end);
labels_prediction = labels_learning_avg(index_prediction);
tim(labels_prediction ~= labels_validation) = labels_prediction(labels_prediction ~= labels_validation);

%% Compute Task-Identification (SI) rates and confusion matrix
rate = nan(1,numTasks);
CM = nan(numTasks,numTasks);
for i = 1:numTasks 
    temp = tim((i-1)*num_validation_subjs+1:(i-1)*num_validation_subjs+num_validation_subjs);
    rate(i) = nnz(temp == 0)/num_validation_subjs;
    
    % Confusion Matrix
    for j = 1:numTasks
        if i == j
            CM(i,j) = nnz(temp == 0)/num_validation_subjs;
        else
            CM(i,j) = nnz(temp == j)/num_validation_subjs;
        end
    end
    
end